uniform sampler2D primary_reference_texture;  // the pattern texture object
uniform sampler2D secondary_reference_texture;  // the pattern texture object


uniform sampler2D mask_texture; // the mask texture object

uniform highp float threshold;

uniform lowp int populateGreenChannel;
uniform lowp float drawBlueValue;

varying highp vec2 v_maskTextureCoordinate;
varying highp vec2 v_referenceTextureCoordinate;
varying highp vec4 v_compareColor;

varying lowp float useSecondaryTexture;






void main()
{
    mediump vec3 currentMask = texture2D(mask_texture, v_maskTextureCoordinate).rgb;
    
    lowp float maskAlpha;
    
    if(drawBlueValue == 1.0)
    {
        maskAlpha = (1.0 - currentMask.b);
    }
    
    else
    {
        // fill the green channel with the current red channel
        if(populateGreenChannel == 1)
        {
            currentMask.g = currentMask.r;
        }
        
        // repeat the green value (so we don't need to roll back undo when changing threshold)
        currentMask.r = currentMask.g;
        maskAlpha = (1.0 - currentMask.g);
    }
    
    
    mediump vec4 currentColor;
    
    if(useSecondaryTexture == 0.0)
    {
        currentColor = texture2D(primary_reference_texture, v_referenceTextureCoordinate);
        currentColor.a = (currentColor.a * maskAlpha); // the mask should't cross alpha boundaries on the primary texture
    }
    
    else
    {
        currentColor = texture2D(secondary_reference_texture, v_referenceTextureCoordinate);
    }

    
    mediump vec4 distancev4 = abs(currentColor - v_compareColor);
    
    mediump float distance = (distancev4.r + distancev4.g + distancev4.b + distancev4.a) / 2.0;
    distance = clamp(distance, 0.0, 254.0/255.0); // clamp it so it doens't go all the way to 255 (we reserve that to marking as seen)
    
    
    //distance = distance / 2.0;
    
    
    gl_FragColor = vec4(currentMask.r, currentMask.g, currentMask.b, distance);
    
    //gl_FragColor = currentColor;
}
