

attribute vec4 vertexAttribPosition;

uniform sampler2D primary_reference_texture;  // the pattern texture object
uniform sampler2D secondary_reference_texture;  // the pattern texture object
uniform sampler2D mask_texture; // the mask texture object

uniform highp mat4 primaryReferenceTextureTransform;
uniform highp mat4 secondaryReferenceTextureTransform;

uniform highp vec2 compare_point;

varying highp vec2 v_maskTextureCoordinate;
varying highp vec2 v_referenceTextureCoordinate;

uniform lowp int populateGreenChannel;
uniform lowp float drawBlueValue;

varying lowp float useSecondaryTexture;


varying highp vec4 v_compareColor;


void main()
{
    highp vec4 textureCoord =  vec4(vertexAttribPosition.xy * 0.5 + 0.5, 0.0, 1.0);
    
    // pull the three compary points, read their textures and figure out if we're using the primary or secondary texture
    
    highp vec3 maskingComparePoint = texture2D(mask_texture, compare_point.xy).rgb;
    
    highp vec4 comparePointTransformed = primaryReferenceTextureTransform * vec4(compare_point.xy, 0.0, 1.0);
    highp vec4 primaryCompareColor = texture2D(primary_reference_texture, comparePointTransformed.xy);
    
    if (comparePointTransformed.x < 0.0 || comparePointTransformed.x > 1.0 || comparePointTransformed.y < 0.0 || comparePointTransformed.y > 1.0 )
    {
        primaryCompareColor.a = 0.0; // primary color is transparent if we're outside of it's bounds
    }
    
    comparePointTransformed = secondaryReferenceTextureTransform * vec4(compare_point.xy, 0.0, 1.0);
    highp vec4 secondaryCompareColor = texture2D(secondary_reference_texture, comparePointTransformed.xy);
    
    
    
    mediump float comparePointAlpha;
    
    if(drawBlueValue == 1.0)
    {
        comparePointAlpha = (1.0 - maskingComparePoint.b);
    }
    
    else
    {
        // fill the green channel with the current red channel
        if(populateGreenChannel == 1)
        {
            maskingComparePoint.g = maskingComparePoint.r;
        }
        
        // use the green channel to find the current value of the compare point mask
        comparePointAlpha = (1.0 - maskingComparePoint.g);
    }
    
    
    comparePointAlpha = comparePointAlpha * primaryCompareColor.a;
    
    if(comparePointAlpha > 0.1)
    {
        useSecondaryTexture = 0.0;
        
        v_referenceTextureCoordinate = (primaryReferenceTextureTransform * textureCoord).xy;
        v_compareColor = primaryCompareColor;
    }
    
    else
    {
        useSecondaryTexture = 1.0;
        
        v_referenceTextureCoordinate = (secondaryReferenceTextureTransform * textureCoord).xy;
        v_compareColor = secondaryCompareColor;
    }
    
    v_maskTextureCoordinate = textureCoord.xy;
    gl_Position = vertexAttribPosition;
}
