//#extension GL_EXT_shader_framebuffer_fetch : require


uniform lowp int undoMode;

uniform sampler2D mask_texture; // the mask texture object
varying highp vec2 v_textureCoordinate;

void main()
{
    //lowp vec4 maskTexelColor = gl_LastFragData[0];
    highp vec4 maskTexelColor = texture2D(mask_texture, v_textureCoordinate);

    // this is a clear, remove all red values and save the current ones to the undo value (green) this marks an undo at the same time as clear
    if(undoMode == 0)
    {
        gl_FragColor = vec4(0.0,maskTexelColor.r,maskTexelColor.b,maskTexelColor.a);
    }
    
    // this is markMaskUndo, copy all red values into green. leave red in place
    else if(undoMode == 1)
    {
        gl_FragColor = vec4(maskTexelColor.r,maskTexelColor.r,maskTexelColor.b,maskTexelColor.a);
    }
    
    // this is maskUndo, swap all red and green values
    else if(undoMode == 2)
    {
        gl_FragColor = vec4(maskTexelColor.g,maskTexelColor.r,maskTexelColor.b,maskTexelColor.a);
    }
    
    // this is markMaskRollback, copy all red values into blue
    else if(undoMode == 3)
    {
        gl_FragColor = vec4(maskTexelColor.r,maskTexelColor.g,maskTexelColor.r,maskTexelColor.a);
    }
    
    // this is maskRollback, copy all blue values into red
    else if(undoMode == 4)
    {
        gl_FragColor = vec4(maskTexelColor.b,maskTexelColor.r,maskTexelColor.b,maskTexelColor.a);
    }
    
    // this is a clear on the base edit, this preserves r and g but sets all b values to clear
    else if(undoMode == 5)
    {
        gl_FragColor = vec4(maskTexelColor.r, maskTexelColor.g, 0.0, 1.0);
    }

    // invert current mask in r, populate undo g channel, leave b as is
    else if(undoMode == 6)
    {
        gl_FragColor = vec4(1.0-maskTexelColor.r, maskTexelColor.r, maskTexelColor.b, maskTexelColor.a);
    }
    //
    else if(undoMode == 7)
    {
        gl_FragColor = vec4(maskTexelColor.r, maskTexelColor.g, 1.0-maskTexelColor.b, maskTexelColor.a);
    }


    
}
